==> munit-remote-2.3.14-sources.jar: org/mule/munit/remote/properties/Parameterization.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.properties;

import java.util.Map;

/**
 * A suite to be run with different parameters
 *
 * @author Mulesoft Inc.
 * @since 2.2.0
 */
public class Parameterization {

  private String parameterizationName;
  private Map<String, String> parameters;

  public Parameterization(String parameterizationName, Map<String, String> parameters) {
    this.parameterizationName = parameterizationName;
    this.parameters = parameters;
  }

  public String getParameterizationName() {
    return parameterizationName;
  }

  public Map<String, String> getParameters() {
    return parameters;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    Parameterization that = (Parameterization) o;

    if (!parameterizationName.equals(that.parameterizationName)) {
      return false;
    }
    return parameters.equals(that.parameters);
  }

  @Override
  public int hashCode() {
    int result = parameterizationName.hashCode();
    result = 31 * result + parameters.hashCode();
    return result;
  }
}

==> munit-remote-3.2.1-sources.jar: org/mule/munit/remote/properties/Parameterization.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.remote.properties;

import java.util.Map;

/**
 * A suite to be run with different parameters
 *
 * @author Mulesoft Inc.
 * @since 2.2.0
 */
public class Parameterization {

  private String parameterizationName;
  private Map<String, Object> parameters;

  public Parameterization(String parameterizationName, Map<String, Object> parameters) {
    this.parameterizationName = parameterizationName;
    this.parameters = parameters;
  }

  public String getParameterizationName() {
    return parameterizationName;
  }

  public Map<String, Object> getParameters() {
    return parameters;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    Parameterization that = (Parameterization) o;

    if (!parameterizationName.equals(that.parameterizationName)) {
      return false;
    }
    return parameters.equals(that.parameters);
  }

  @Override
  public int hashCode() {
    int result = parameterizationName.hashCode();
    result = 31 * result + parameters.hashCode();
    return result;
  }
}
